==> haskell-irc-core-2.12-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-AKej30u3vzvJ0dkhFwBt4B
key:                  irc-core-2.12-AKej30u3vzvJ0dkhFwBt4B
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  127febfd1e99deda40505c92b4bbb634
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-AKej30u3vzvJ0dkhFwBt4B
depends:
    attoparsec-0.14.4-Fn7js8xKpz57gY212YnEkw base-4.17.2.1
    base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT
    bytestring-0.11.5.3 hashable-1.4.6.0-AVmZwVVVmv9PclG6VBq0Z
    primitive-0.9.1.0-4gbRHMYHSCF2lptKn8Ww53 text-2.0.2 time-1.12.2
    vector-0.13.2.0-E9z8CkzpYQwAFSNyB7dwgD

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.12-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-4a675YhkvKWHBUuumimHp3
key:                  irc-core-2.12-4a675YhkvKWHBUuumimHp3
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  8448403c713b35e044c7145efaed63c4
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-4a675YhkvKWHBUuumimHp3
depends:
    attoparsec-0.14.4-7a1Wj008Q4s1weDZNikOjh base-4.17.2.1
    base64-bytestring-1.2.1.0-JNpFHiqgYkrlFIHcalimL bytestring-0.11.5.3
    hashable-1.4.6.0-HNsjIjcKtfz4EPsBV3Crzv
    primitive-0.9.1.0-IYGvfPhp8bDLAkMykHY1iR text-2.0.2 time-1.12.2
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
